@@ -93,6 +93,40 @@
 #'  level one error generating function
 #' @param arima_mod A list indicating the ARIMA model to pass to arima.sim. 
 #'             See \code{\link{arima.sim}} for examples.
+#' @param contrasts An optional list that specifies the contrasts to be used 
+#'  for factor variables (i.e. those variables with .f or .c). 
+#'  See \code{\link{contrasts}} for more detail.
+#' @param homogeneity Either TRUE (default) indicating homogeneity of variance
+#'  assumption is assumed or FALSE to indicate desire to generate heterogeneity 
+#'  of variance.
+#' @param heterogeneity_var Variable name as a character string to use for 
+#'  heterogeneity of variance simulation.
+#' @param cross_class_params A list of named parameters when cross classified 
+#'  data structures are desired. Must include the following arguments:
+#'   \itemize{
+#'    \item num_ids: The number of cross classified clusters. These are in 
+#'         addition to the typical cluster ids
+#'    \item random_param: This argument is a list of arguments passed to 
+#'       \code{\link{sim_rand_eff}}. These must include:
+#'      \itemize{
+#'       \item random_var: The variance of the cross classified random effect
+#'       \item rand_gen: The random generating function used to generate the 
+#'          cross classified random effect.
+#'      }
+#'      Optional elements are:
+#'    \itemize{
+#'        \item ther: Theorectial mean and variance from rand_gen,
+#'        \item ther_sim: Simulate mean/variance for standardization purposes,
+#'        \item cor_vars: Correlation between random effects,
+#'        \item ...: Additional parameters needed for rand_gen function.
+#'    } 
+#'   }
+#' @param knot_args A nested list of named knot arguments. See \code{\link{sim_knot}} 
+#'  for more details. Arguments must include:
+#'    \itemize{
+#'      \item var
+#'      \item knot_locations
+#'    }
 #' @param missing TRUE/FALSE flag indicating whether missing data should be 
 #'  simulated.
 #' @param missing_args Additional missing arguments to pass to the missing_data 
@@ -120,12 +154,18 @@
 #' @param arima_fit_mod Valid nlme syntax for fitting serial correlation structures.
 #'   See \code{\link{corStruct}} for help. This must be specified to 
 #'   include serial correlation.
+#' @param general_mod Valid model syntax. This syntax can be from any R package. 
+#'   By default, broom is used to extract model result information. Note, 
+#'   package must be defined or loaded prior to running the sim_pow function.
+#' @param general_extract A valid function to extract model results if 
+#'   general_mod argument is used. This argument is primarily used if extracting model
+#'   results is not possibly using the broom package. If this is left NULL (default), 
+#'   broom is used to collect model results.
 #' @param ... Currently not used.
 #' @importFrom dplyr group_by
 #' @importFrom dplyr summarise
 #' @importFrom dplyr '%>%'
 #' @importFrom dplyr left_join
-#' @importFrom tidyr nest
 #' 
 #' @examples 
 #' 
@@ -166,7 +206,7 @@
 #' alpha <- .01
 #' pow_dist <- "t"
 #' pow_tail <- 2
-#' replicates <- 2
+#' replicates <- 1
 #' terms_vary <- list(n = c(20, 40, 60, 80, 100), error_var = c(5, 10, 20))
 #' power_out <- sim_pow(fixed = fixed, fixed_param = fixed_param, cov_param = cov_param,
 #'                      n = n, error_var = error_var, with_err_gen = with_err_gen, 
@@ -198,7 +238,7 @@
 #' alpha <- .01
 #' pow_dist <- "z"
 #' pow_tail <- 2
-#' replicates <- 2
+#' replicates <- 1
 #' power_out <- sim_pow(fixed = fixed, random = random, random3 = random3,
 #'                      fixed_param = fixed_param, 
 #'                      random_param = random_param, 
@@ -221,11 +261,15 @@ sim_pow <- function(fixed, random = NULL, random3 = NULL, fixed_param,
                     unbal = list("level2" = FALSE, "level3" = FALSE), 
                     unbal_design = list("level2" = NULL, "level3" = NULL),
                     lvl1_err_params = NULL, arima_mod = list(NULL),
+                    contrasts = NULL, homogeneity = TRUE,
+                    heterogeneity_var = NULL, cross_class_params = NULL,
+                    knot_args = list(NULL),
                     missing = FALSE, missing_args = list(NULL),
                    pow_param, alpha, pow_dist = c("z", "t"), pow_tail = c(1, 2), 
                     replicates, terms_vary = NULL, raw_power = TRUE, 
                    lm_fit_mod = NULL, lme4_fit_mod = NULL, nlme_fit_mod = NULL,
-                   arima_fit_mod = NULL, ...) {
+                   arima_fit_mod = NULL, general_mod = NULL, general_extract = NULL, 
+                   ...) {
   
   args <- list(fixed = fixed, random = random, random3 = random3,
                fixed_param = fixed_param, random_param = random_param,
@@ -236,11 +280,15 @@ sim_pow <- function(fixed, random = NULL, random3 = NULL, fixed_param,
                fact_vars = fact_vars, unbal = unbal,
                unbal_design = unbal_design,
                lvl1_err_params = lvl1_err_params,
-               arima_mod = arima_mod, missing = missing, 
+               arima_mod = arima_mod, contrasts = contrasts,
+               homogeneity = homogeneity, heterogeneity_var = heterogeneity_var,
+               cross_class_params = cross_class_params, 
+               knot_args = knot_args, missing = missing, 
                missing_args = missing_args, pow_param = pow_param, 
                alpha = alpha, pow_dist = pow_dist, pow_tail = pow_tail, 
                lm_fit_mod = lm_fit_mod, lme4_fit_mod = lme4_fit_mod, 
-               nlme_fit_mod = nlme_fit_mod, arima_fit_mod = arima_fit_mod)
+               nlme_fit_mod = nlme_fit_mod, arima_fit_mod = arima_fit_mod,
+               general_mod = general_mod, general_extract = general_extract)
   
   if(!is.null(terms_vary)) {
     args[names(terms_vary)] <- NULL
@@ -338,12 +386,14 @@ sim_pow <- function(fixed, random = NULL, random3 = NULL, fixed_param,
     }
   }
   
-  grp_by <- lapply(c('var', names(terms_vary)), as.symbol)
+  grp_by <- lapply(c('term', names(terms_vary)), as.symbol)
   
   power <- temp_pow %>%
     dplyr::group_by_(.dots = grp_by) %>%
-    dplyr::summarise(avg_test_stat = mean(test_stat),
-                     sd_test_stat = sd(test_stat),
+    dplyr::summarise(avg_test_stat = mean(estimate),
+                     sd_test_stat = sd(estimate),
+                     avg_std_err = mean(std.error),
+                     sd_std_err = sd(std.error),
                      power = mean(reject),
                      num_reject = sum(reject),
                      num_repl = replicates)
@@ -443,9 +493,38 @@ sim_pow <- function(fixed, random = NULL, random3 = NULL, fixed_param,
 #'  as the level two or three sample size. These are specified as a named list in which
 #'  level two sample size is controlled via "level2" and level three sample size is 
 #'  controlled via "level3".
+#' @param contrasts An optional list that specifies the contrasts to be used 
+#'   for factor variables (i.e. those variables with .f or .c). 
+#'   See \code{\link{contrasts}} for more detail.
 #' @param outcome_type A vector specifying the type of outcome, must be either
 #'   logistic or poisson. Logitstic outcome will be 0/1 and poisson outcome will
 #'   be counts.
+#' @param cross_class_params A list of named parameters when cross classified 
+#'  data structures are desired. Must include the following arguments:
+#'   \itemize{
+#'    \item num_ids: The number of cross classified clusters. These are in 
+#'         addition to the typical cluster ids
+#'    \item random_param: This argument is a list of arguments passed to 
+#'       \code{\link{sim_rand_eff}}. These must include:
+#'      \itemize{
+#'       \item random_var: The variance of the cross classified random effect
+#'       \item rand_gen: The random generating function used to generate the 
+#'          cross classified random effect.
+#'      }
+#'      Optional elements are:
+#'    \itemize{
+#'        \item ther: Theorectial mean and variance from rand_gen,
+#'        \item ther_sim: Simulate mean/variance for standardization purposes,
+#'        \item cor_vars: Correlation between random effects,
+#'        \item ...: Additional parameters needed for rand_gen function.
+#'    } 
+#'   }
+#' @param knot_args A nested list of named knot arguments. See \code{\link{sim_knot}} 
+#'  for more details. Arguments must include:
+#'    \itemize{
+#'      \item var
+#'      \item knot_locations
+#'    }
 #' @param missing TRUE/FALSE flag indicating whether missing data should be 
 #'  simulated.
 #' @param missing_args Additional missing arguments to pass to the missing_data 
@@ -470,6 +549,13 @@ sim_pow <- function(fixed, random = NULL, random3 = NULL, fixed_param,
 #' @param lme4_fit_mod Valid lme4 syntax to be used for model fitting.
 #' @param glm_fit_family Valid family syntax to pass to the glm function.
 #' @param lme4_fit_family Valid lme4 family specification passed to glmer.
+#' @param general_mod Valid model syntax. This syntax can be from any R package. 
+#'   By default, broom is used to extract model result information. Note, 
+#'   package must be defined or loaded prior to running the sim_pow function.
+#' @param general_extract A valid function to extract model results if 
+#'   general_mod argument is used. This argument is primarily used if extracting model
+#'   results is not possibly using the broom package. If this is left NULL (default), 
+#'   broom is used to collect model results.
 #' @param ... Current not used.
 #' @importFrom dplyr group_by
 #' @importFrom dplyr summarise
@@ -501,17 +587,21 @@ sim_pow <- function(fixed, random = NULL, random3 = NULL, fixed_param,
 #' 
 #' @export 
 sim_pow_glm <- function(fixed, random = NULL, random3 = NULL, fixed_param, 
-                    random_param = list(NULL), random_param3 = list(NULL), 
-                    cov_param, k = NULL, n, p = NULL, 
-                    data_str, cor_vars = NULL, fact_vars = list(NULL), 
-                    unbal = list("level2" = FALSE, "level3" = FALSE), 
-                    unbal_design = list("level2" = NULL, "level3" = NULL),
-                    outcome_type, 
-                    missing = FALSE, missing_args = list(NULL),
-                  pow_param, alpha, pow_dist = c("z", "t"), pow_tail = c(1, 2), 
-                    replicates, terms_vary = NULL, raw_power = TRUE, 
-                  glm_fit_mod = NULL, lme4_fit_mod = NULL, 
-                  glm_fit_family = NULL, lme4_fit_family = NULL, ...) {
+                        random_param = list(NULL), random_param3 = list(NULL), 
+                        cov_param, k = NULL, n, p = NULL, 
+                        data_str, cor_vars = NULL, fact_vars = list(NULL), 
+                        unbal = list("level2" = FALSE, "level3" = FALSE), 
+                        unbal_design = list("level2" = NULL, "level3" = NULL),
+                        contrasts = NULL,
+                        outcome_type, cross_class_params = NULL,
+                        knot_args = list(NULL),
+                        missing = FALSE, missing_args = list(NULL),
+                        pow_param, alpha, pow_dist = c("z", "t"), 
+                        pow_tail = c(1, 2), 
+                        replicates, terms_vary = NULL, raw_power = TRUE, 
+                        glm_fit_mod = NULL, lme4_fit_mod = NULL, 
+                        glm_fit_family = NULL, lme4_fit_family = NULL, 
+                        general_mod = NULL, general_extract = NULL, ...) {
   
   args <- list(fixed = fixed, random = random, random3 = random3,
                fixed_param = fixed_param, random_param = random_param,
@@ -519,12 +609,15 @@ sim_pow_glm <- function(fixed, random = NULL, random3 = NULL, fixed_param,
                cov_param = cov_param, k = k, n = n, p = p, 
                data_str = data_str, cor_vars = cor_vars, 
                fact_vars = fact_vars, unbal = unbal, unbal_design = unbal_design,
-               outcome_type = outcome_type, 
+               contrasts = contrasts,
+               outcome_type = outcome_type, cross_class_params = cross_class_params,
+               knot_args = knot_args, 
                missing = missing, missing_args = missing_args,
                pow_param = pow_param, alpha = alpha, pow_dist = pow_dist, 
                pow_tail = pow_tail, glm_fit_mod = glm_fit_mod, 
                lme4_fit_mod = lme4_fit_mod, glm_fit_family = glm_fit_family,
-               lme4_fit_family = lme4_fit_family)
+               lme4_fit_family = lme4_fit_family, 
+               general_mod = general_mod, general_extract = general_extract)
   
   if(!is.null(terms_vary)) {
     args[names(terms_vary)] <- NULL
@@ -622,12 +715,14 @@ sim_pow_glm <- function(fixed, random = NULL, random3 = NULL, fixed_param,
     }
   }
   
-  grp_by <- lapply(c('var', names(terms_vary)), as.symbol)
+  grp_by <- lapply(c('term', names(terms_vary)), as.symbol)
   
   power <- temp_pow %>%
     dplyr::group_by_(.dots = grp_by) %>%
-    dplyr::summarise(avg_test_stat = mean(test_stat),
-                     sd_test_stat = sd(test_stat),
+    dplyr::summarise(avg_test_stat = mean(estimate),
+                     sd_test_stat = sd(estimate),
+                     avg_std_err = mean(std.error),
+                     sd_std_err = sd(std.error),
                      power = mean(reject),
                      num_reject = sum(reject),
                      num_repl = replicates)
